Package 'grandR'

Title: Comprehensive Analysis of Nucleotide Conversion Sequencing Data
Description: Nucleotide conversion sequencing experiments have been developed to add a temporal dimension to RNA-seq and single-cell RNA-seq. Such experiments require specialized tools for primary processing such as GRAND-SLAM, (see 'Jürges et al' <doi:10.1093/bioinformatics/bty256>) and specialized tools for downstream analyses. 'grandR' provides a comprehensive toolbox for quality control, kinetic modeling, differential gene expression analysis and visualization of such data. Fast Wilcoxon tests are supported via the 'presto' package (available at https://github.com/immunogenomics/presto).
Authors: Florian Erhard [aut, cre] , Teresa Rummel [ctb], Julian Selke [ctb]
Maintainer: Florian Erhard <[email protected]>
License: Apache License (>= 2)
Version: 0.2.7
Built: 2026-05-14 05:39:05 UTC
Source: https://github.com/erhard-lab/grandr

Help Index